summaryrefslogtreecommitdiffstats
path: root/widget/src/helpers.rs
diff options
context:
space:
mode:
Diffstat (limited to 'widget/src/helpers.rs')
-rw-r--r--widget/src/helpers.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/widget/src/helpers.rs b/widget/src/helpers.rs
index 3f34d165..a643add3 100644
--- a/widget/src/helpers.rs
+++ b/widget/src/helpers.rs
@@ -123,20 +123,20 @@ where
Button::new(content)
}
/// Creates a new [`Tooltip`] with the provided content, tooltip text, and [`tooltip::Position`].
///
/// [`Tooltip`]: crate::Tooltip
/// [`tooltip::Position`]: crate::tooltip::Position
pub fn tooltip<'a, Message, Theme, Renderer>(
content: impl Into<Element<'a, Message, Theme, Renderer>>,
- tooltip: impl ToString,
+ tooltip: impl Into<Element<'a, Message, Theme, Renderer>>,
position: tooltip::Position,
) -> crate::Tooltip<'a, Message, Theme, Renderer>
where
Theme: container::StyleSheet + text::StyleSheet,
Renderer: core::text::Renderer,
{
- Tooltip::new(content, tooltip.to_string(), position)
+ Tooltip::new(content, tooltip, position)
}
/// Creates a new [`Text`] widget with the provided content.
@@ -123,20 +123,20 @@ where
Button::new(content)
}
-/// Creates a new [`Tooltip`] with the provided content, tooltip text, and [`tooltip::Position`].
+/// Creates a new [`Tooltip`] with the provided content, tooltip element, and [`tooltip::Position`].
///
/// [`Tooltip`]: crate::Tooltip